# jovsatools
> my personal toolbox 🧰


### Usefull Links
* [Design document](https://jovsa.github.io/jovsatools/design_document/): outlines the choices, considerations and tradeoffs made 

* [Usefull commands](https://github.com/jovsa/jovsatools/blob/master/Makefile): when running things locally

* Link to [documentation](https://jovsa.github.io/jovsatools)

* Link to [notebooks](https://github.com/jovsa/jovsatools/tree/master/notebooks)

* pypi pacakge detial:
    * to import run: `pip install jovsatools`
    * location of [pypi package](https://pypi.org/project/jovsatools/)
    * to push an updated version of the package [details here](http://nbdev.fast.ai/tutorial/#Upload-to-pypi)


### FAQ
* What to get started? [look here](https://github.com/jovsa/jovsatools/blob/master/CONTRIBUTING.md#do-you-want-to-contribute-to-the-documentation)

* Found bugs🐛? [look here](https://github.com/jovsa/jovsatools/blob/master/CONTRIBUTING.md#did-you-find-a-bug)

* Have ideas? [more information here](https://github.com/jovsa/jovsatools/blob/master/CONTRIBUTING.md#pr-submission-guidelines)

* Known bugs🕸️: There are some documentation rendering issues. Please go to the notebooks directly in such cases.

[🔮](https://jovsa.github.io/)
